@@ -84,6 +84,8 @@ function(x, y, n.hidden=2, n.hidden2=2, w=NULL, tau=0.5, n.ensemble=1,
     if (!is.matrix(x)) stop("\"x\" must be a matrix")
     if (!is.matrix(y)) stop("\"y\" must be a matrix")
     if (ncol(y) != 1) stop("\"y\" must be univariate")
+    if (any(is.na(c(x, y)))) stop("missing values in \"x\" or \"y\"")
+    if (any(apply(x, 2, sd) < .Machine$double.eps^0.5)) stop("zero variance column(s) in \"x\"")
     if (any((tau > 1) | (tau < 0))) stop("invalid \"tau\"")
     if (identical(Th, linear))
         stop("use \"qrnn.fit\" for linear models")
@@ -98,7 +100,7 @@ function(x, y, n.hidden=2, n.hidden2=2, w=NULL, tau=0.5, n.ensemble=1,
     y.center <- attr(y, "scaled:center")
     y.scale <- attr(y, "scaled:scale")
     lower.scaled <- (lower-y.center)/y.scale
-    weights <- list()
+    weights <- vector("list", n.ensemble)
     if(trace) cat("tau =", unique(tau), "\n", sep=" ")
     for (i in seq(n.ensemble)){
         if(trace) cat(i, "/", n.ensemble, "\n", sep="")
